#!/bin/bash

KEYDIR=/var/lib/eos-payg-keys
EFIVARDIR=/sys/firmware/efi/efivars
DEVKEYDIR=/usr/share/eos-payg
KEYFILE="${KEYDIR}"/PK.key
CERTFILE="${KEYDIR}"/PK.pem
TMPDIR=""

cleanup()
{
  if [ -d "${TMPDIR}" ]; then
    rm -f "${TMPDIR}"/noPK.esl "${TMPDIR}"/noPK.auth
    rmdir "${TMPDIR}"
  fi
}

BAIL()
{
  echo "$0 : $1" 1>&2
  cleanup
  exit 1
}

if [[ $1 == "-h" ]] || [[ $1 == "--help" ]]; then
  echo "Usage:"
  echo "   $0"
  echo ""
  echo "This script unsets the system PK which will allow booting unsigned"
  echo "software."
  exit 0
fi

TMPDIR=$(mktemp -d)

if [ ! -f "${KEYFILE}" ]; then
  echo "This may not be a developer device, or the contents of ${KEYDIR} have been lost"
  echo "Will attempt to unlock with current developer key"

  KEYFILE=( "${DEVKEYDIR}"/EOS-PAYG-DEVELOPER*.key )
  CERTFILE=( "${DEVKEYDIR}"/EOS-PAYG-DEVELOPER*.pem )
fi

touch "${TMPDIR}"/noPK.esl || BAIL "Unable to write empty signature list"

sign-efi-sig-list -k "${KEYFILE}" -c "${CERTFILE}" PK "${TMPDIR}"/noPK.esl "${TMPDIR}"/noPK.auth
[ $? -eq 0 ] || BAIL "Unable to create signed PK clear request"

chattr -fi "${EFIVARDIR}"/PK-8be4df61-93ca-11d2-aa0d-00e098032b8c || BAIL "Failed to make PK mutable"
efi-updatevar -f "${TMPDIR}"/noPK.auth PK || BAIL "Failed to clear PK"

cleanup

echo "$0": successfully completed, secure boot PK removed
echo "Reboot to disable Secure Boot"
